{% spaceless %}
<figure class="op-interactive">
  <iframe class="instagram-media instagram-media-rendered" id="instagram-embed-0" src="https://www.instagram.com/p/{{instagram_id}}/embed/captioned/?v=7" allowtransparency="true" frameborder="0"></iframe>
</figure>
{% endspaceless %}
